[libpng15] Bump version to libpng-1.5.7beta03
diff --git a/INSTALL b/INSTALL
index 353bfff..e6979c6 100644
--- a/INSTALL
+++ b/INSTALL
@@ -133,3 +133,23 @@
 Further information can be found in the README and libpng-manual.txt
 files, in the individual makefiles, in png.h, and the manual pages
 libpng.3 and png.5.
+
+Using the ./configure script -- 16 December 2002.
+=================================================
+
+The ./configure script should work compatibly with what scripts/makefile.*
+did, however there are some options you might need to add to configure
+explicitly, which previously was done semi-automatically (if you didn't edit
+scripts/makefile.* yourself, that is)
+
+CFLAGS="-Wall -O -funroll-loops \
+-malign-loops=2 -malign-functions=2" ./configure --prefix=/usr/include \
+--with-pkgconfigdir=/usr/lib/pkgconfig --includedir=/usr/include
+
+You can alternatively specify --includedir=/usr/include, /usr/local/include,
+/usr/include/libpng%NN%, or whatever.
+
+If you find that the configure script is out-of-date or is not supporting
+your platform properly, try running autogen.sh to regenerate "configure",
+"Makefile.in", and the other configuration files. Then try configure again.
+
diff --git a/LICENSE b/LICENSE
index 004c1d9..9db2f71 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 12, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
 Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 12, 2011
+November 16, 2011
diff --git a/README b/README
index 48d397d..7d8dc17 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.7beta03 - November 12, 2011 (shared library 15.0)
+README for libpng version 1.5.7beta03 - November 16, 2011 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/arm/filter_neon.S b/arm/filter_neon.S
index a65ab0c..1f10328 100644
--- a/arm/filter_neon.S
+++ b/arm/filter_neon.S
@@ -8,6 +8,10 @@
  * and license in png.h
  */
 
+#if defined(__linux__) && defined(__ELF__)
+.section .note.GNU-stack,"",%progbits /* mark stack as non-executable */
+#endif
+
 #ifdef __ELF__
 #   define ELF
 #else
diff --git a/configure b/configure
index 0d87ba2..2c8fa31 100755
--- a/configure
+++ b/configure
@@ -1405,7 +1405,7 @@
   --enable-fast-install[=PKGS]
                           optimize for fast installation [default=yes]
   --disable-libtool-lock  avoid locking (might break parallel builds)
-  --enable-arm-neon       Enable ARM NEON optmizations
+  --enable-arm-neon       Enable ARM NEON optimizations
 
 Optional Packages:
   --with-PACKAGE[=ARG]    use PACKAGE [ARG=yes]
diff --git a/configure.ac b/configure.ac
index f123b1f..34cc4b8 100644
--- a/configure.ac
+++ b/configure.ac
@@ -184,10 +184,15 @@
 	[binconfigs='${binconfigs}'])
 AC_SUBST([binconfigs])
 
+# Because GCC by default assembles code with an executable stack, even though it
+# compiles C code with a non-executable stack, it is necessary to do a fixup
+# here (this may by GCC specific)
+AC_SUBST([AM_CCASFLAGS], [--noexecstack])
+
 AC_ARG_ENABLE([arm-neon],
-	AC_HELP_STRING([--enable-arm-neon], [Enable ARM NEON optmizations]),
+	AC_HELP_STRING([--enable-arm-neon], [Enable ARM NEON optimizations]),
 	[if test "${enableval}" = yes; then
-		AC_DEFINE([PNG_ARM_NEON], [1], [Enable ARM NEON optmizations])
+		AC_DEFINE([PNG_ARM_NEON], [1], [Enable ARM NEON optimizations])
 		AC_DEFINE([PNG_ALIGNED_MEMORY_SUPPORTED], [1], [Align row buffers])
 	fi])
 AM_CONDITIONAL([PNG_ARM_NEON], [test "${enable_arm_neon:-no}" = yes])
diff --git a/libpng-manual.txt b/libpng-manual.txt
index f030b91..a383ae1 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.7beta03 - November 12, 2011
+ libpng version 1.5.7beta03 - November 16, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.7beta03 - November 12, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -4566,7 +4566,7 @@
 
 XIV. Y2K Compliance in libpng
 
-November 12, 2011
+November 16, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
diff --git a/libpng.3 b/libpng.3
index 366800b..0816efc 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "November 12, 2011"
+.TH LIBPNG 3 "November 16, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta03
 .SH SYNOPSIS
@@ -1037,7 +1037,7 @@
 .SH LIBPNG.TXT
 libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.7beta03 - November 12, 2011
+ libpng version 1.5.7beta03 - November 16, 2011
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
@@ -1048,7 +1048,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.7beta03 - November 12, 2011
+ libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2011 Glenn Randers-Pehrson
 
@@ -5604,7 +5604,7 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-November 12, 2011
+November 16, 2011
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
@@ -5869,7 +5869,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.7beta03 - November 12, 2011:
+Libpng version 1.5.7beta03 - November 16, 2011:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5892,7 +5892,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 12, 2011, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5991,7 +5991,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-November 12, 2011
+November 16, 2011
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index e571152..7a6fd7d 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "November 12, 2011"
+.TH LIBPNGPF 3 "November 16, 2011"
 .SH NAME
 libpng \- Portable Network Graphics (PNG) Reference Library 1.5.7beta03
 (private functions)
diff --git a/png.5 b/png.5
index 9d3c045..8235fe3 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "November 12, 2011"
+.TH PNG 5 "November 16, 2011"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index bfbe0c3..1a84cb2 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.7beta03 - November 12, 2011
+ * libpng version 1.5.7beta03 - November 16, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 4697678..b1e89c5 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.7beta03 - November 12, 2011
+libpng version 1.5.7beta03 - November 16, 2011
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 3a47bf7..2854675 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.7beta03 - November 12, 2011
+ * libpng version 1.5.7beta03 - November 16, 2011
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 88888c9..5510ff7 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
 
-Makefiles for  libpng version 1.5.7beta03 - November 12, 2011
+Makefiles for  libpng version 1.5.7beta03 - November 16, 2011
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 574120a..e5fccbb 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -3,7 +3,7 @@
 
 /* pnglibconf.h - library build configuration */
 
-/* Libpng 1.5.7beta03 - November 12, 2011 */
+/* Libpng 1.5.7beta03 - November 16, 2011 */
 
 /* Copyright (c) 1998-2011 Glenn Randers-Pehrson */
diff --git a/png.h b/png.h
index 8e779c3..9896e0c 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.7beta03 - November 12, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 12, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -195,7 +195,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 12, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -307,7 +307,7 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    November 12, 2011
+ *    November 16, 2011
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
@@ -373,7 +373,7 @@
 /* Version information for png.h - this should match the version in png.c */
 #define PNG_LIBPNG_VER_STRING "1.5.7beta03"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.7beta03 - November 12, 2011\n"
+     " libpng version 1.5.7beta03 - November 16, 2011\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.7beta03 - November 12, 2011
+ * libpng version 1.5.7beta03 - November 16, 2011
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 12, 2011: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.7beta03 - November 16, 2011: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -195,7 +195,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 12, 2011, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.7beta03, November 16, 2011, are
  * Copyright (c) 2004, 2006-2011 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5